@@ -51,6 +51,7 @@ struct _ClearlooksStyle
 
 	ClearlooksStyles style;
 
+	guint8   reliefstyle;
 	guint8   menubarstyle;
 	guint8   toolbarstyle;
 	GdkColor focus_color;
@@ -67,6 +68,7 @@ struct _ClearlooksStyleClass
 	GtkStyleClass parent_class;
 
 	ClearlooksStyleFunctions style_functions[CL_NUM_STYLES];
+	ClearlooksStyleConstants style_constants[CL_NUM_STYLES];
 };
 
 GE_INTERNAL void clearlooks_style_register_type (GTypeModule *module);
